@@ -1,6 +1,3 @@
-import PyGine.PyGineGame as Window
-import pygame as pg
-import pygame.gfxdraw as gfxdraw
 from PyGine.Component import Component
 
 
